#!/usr/bin/env python3
# -*- coding:utf-8 -*-
###
# File: required.py
# Created: Tuesday, 28th July 2020 12:34:09 pm
# Author: Rakibul Yeasin (ryeasin03@gmail.com)
# -----
# Last Modified: Tuesday, 28th July 2020 8:32:09 pm
# Modified By: Rakibul Yeasin (ryeasin03@gmail.com)
# -----
# Copyright (c) 2020 Slishee
###

import requests

class Request:
    def __init__(self):
        self.headers = {'content-type': "application/json"}
        self.payload = {}

    def get(self, uri, *args, **kwargs):
        if args:
            if kwargs and kwargs['header']:
                self.headers['X-API-Key'] = 'SqD712P3E82xnwOAEOkGd5JZH8s9wRR24TqNFzjk' or kwargs['x_api_key']
                self.res = requests.get(uri, params=args[0], headers=self.headers)
            self.res = requests.get(uri, params=args[0], headers=self.headers)
            self.obj = self.res.json()
            return self.obj
        self.res = requests.get(uri)
        self.obj = self.res.json()
        return self.obj



#!/usr/bin/env python3
# -*- coding:utf-8 -*-
###
# File: __init__.py
# Created: Tuesday, 28th July 2020 2:16:17 pm
# Author: Rakibul Yeasin (ryeasin03@gmail.com)
# -----
# Last Modified: Tuesday, 28th July 2020 8:21:23 pm
# Modified By: Rakibul Yeasin (ryeasin03@gmail.com)
# -----
# Copyright (c) 2020 Slishee
###

import sys
sys.dont_write_bytecode = True

from .Quran_api import Quran
from .Sunnah_api import Sunnah
from .MiddleWare import Request
from .Errors import *

Request = Request
Quran = Quran
Sunnah = Sunnah


#!/usr/bin/env python3
# -*- coding:utf-8 -*-
###
# File: Sunnah_api.py
# Created: Tuesday, 28th July 2020 8:07:54 pm
# Author: Rakibul Yeasin (ryeasin03@gmail.com)
# -----
# Last Modified: Thursday, 6th August 2020 12:41:23 pm
# Modified By: Rakibul Yeasin (ryeasin03@gmail.com)
# -----
# Copyright (c) 2020 Slishee
###

import quran as q
from typing import Dict

class Sunnah:
    """
    sunnah.com api class

    Methods:
        get_root
        get_collections
        get_collections_by_name
        get_list_chapters
        get_list_hadith
        get_hadith
        get_random_hadith
        get_book
        get_books
    """

    def __init__(self) -> None:
        """
        Constructor class

        args
            None

        returns
            None
        """
        self.base: str = "https://api.sunnah.com/v1/"
        self.rq: str = q.Request()

    def get_root(self) -> Dict:
        """
        Returns the root of sunnah.com api

        args:
            None

        return
            json Object
        """
        return self.rq.get(f"{self.base}", header=True)

    def get_collections(self, **kwargs) -> Dict:
        """
        Paginated list of available collections

        args:
            limit   Maximum number of items
            page    Offset for pagination

        returns:
            json Object
        """
        return self.rq.get(f"{self.base}collections", kwargs, header=True)

    def get_collections_by_name(self, name, **kwargs) -> Dict:
        """
        Paginated list of available collections by name

        args:
            name    Name of the collection(Bukhari, Muslim etc)
            limit   Maximum number of items
            page    Offset for pagination

        returns:
            json Object
        """
        if not name:
            raise q.CollectionNameNotFound
        return self.rq.get(f"{self.base}collections/{name}", kwargs, header=True)

    def get_list_chapters(self, name, id, **kwargs) -> Dict:
        """
        Get the list of chapters of a book for a collection

        args:
        """
        if not name or not id:
            raise q.CollectionNameOrIdNotFound
        return self.rq.get(f"{self.base}collections/{name}/books/{id}/chapters", kwargs, header=True)

    def get_list_hadith(self, name, id, **kwargs):
        if not name or not id:
            raise q.CollectionNameOrIdNotFound
        return self.rq.get(f"{self.base}collections/{name}/books/{id}/hadiths", kwargs, header=True)

    def get_hadith(self, name, id, **kwargs):
        if not name or not id:
            raise q.CollectionNameOrIdNotFound
        return self.rq.get(f"{self.base}collections/{name}/hadiths/{id}", kwargs, header=True)

    def get_random_hadith(self):
        return self.rq.get(f"{self.base}hadiths/random", header=True)

    def get_book(self, name, id):
        if not name and id:
            raise q.CollectionNameOrIdNotFound
        return self.rq.get(f"{self.base}collections/{name}/books/{id}", header=True)

    def get_books(self, name, **kwargs):
        if not name:
            raise q.CollectionNameNotFound
        return self.rq.get(f"{self.base}collections/{name}/books", kwargs, header=True)



#!/usr/bin/env python3
# -*- coding:utf-8 -*-
###
# File: api.py
# Created: Tuesday, 28th July 2020 12:31:21 pm
# Author: Rakibul Yeasin (ryeasin03@gmail.com)
# -----
# Last Modified: Wednesday, 29th July 2020 1:34:28 am
# Modified By: Rakibul Yeasin (ryeasin03@gmail.com)
# -----
# Copyright (c) 2020 Slishee
###

import quran as q
from typing import Dict

class Quran:
    """
    quran.com api class

    Contains:
        get_recitations
    """
    def __init__(self) -> None:
        """
        Constructor class

        args
            None

        returns
            None
        """
        self.base: str = "http://api.quran.com/api/v3/"
        self.rq: str = q.Request()

    def get_recitations(self, **kwargs) -> Dict:
        """
        Get list of available Recitations.
        Use language query to get translated names of reciters in specific language(e.g language=ur will send translation names in Urdu).

        args
            language

        returns
            json Object
        """
        return self.rq.get(f"{self.base}options/recitations", kwargs)

    def get_translations(self, **kwargs) -> Dict:
        """
        Get list of available translations.
        args
            None

        returns
            json Object
        """
        return self.rq.get(f"{self.base}options/translations", kwargs)

    def get_languages(self, **kwargs) -> Dict:
        """
        Get all languages.
        You can get translated names of languages in specific language using language query parameter.
        For example:
            obj.get_languages(bn)
        will return language names translated into Bangla

        args:
            language    Specific Laguage in ISO

        returns:
            json Object
        """
        return self.rq.get(f"{self.base}options/languages", kwargs)

    def get_tafsirs(self) -> Dict:
        """
        args:
            None

        returns:
            json Object
        """
        return self.rq.get(f"{self.base}options/tafsirs")

    def get_chapter(self, *args, **kwargs) -> Dict:
        """
        Get list of chapter. Use language query to get translated names of chapter in specific language
        (e.g language=bn will send translation names in Bangla).

        args:
            info      Show insformation (True/False)
            language  Target Language

        returns:
            json Object
        """
        if args:
            if kwargs:
                if kwargs.get("info") and kwargs.get("language"):
                    return self.rq.get(f"{self.base}chapters/{args[0]}/info", kwargs.get("language"))
                elif kwargs.get("info"):
                    return self.rq.get(f"{self.base}chapters/{args[0]}/info")
                elif kwargs.get("language"):
                    return self.rq.get(f"{self.base}chapters/{args[0]}", kwargs.get("language"))
            return self.rq.get(f"{self.base}chapters/{args[0]}")

        if kwargs:
            return self.rq.get(f"{self.base}chapters", kwargs["language"])

        return self.rq.get(f"{self.base}chapters")

    def get_verses(self, chapter_id, **kwargs) -> Dict:
        """
        Get all the verse from specific chapter_id

        args:
            chapter_id
            recitation
            translations
            media
            language        default: en
            page            for paginating the results
            offset
            limit           Control number of verse you want to get with each api call. Max limit is 50
            text_type       could be image[to get image of verse_id] OR words[this will return list of words for verse_id].
                            Allowed Values: words, image
                            default: words

        returns:
            json Object
        """
        return self.rq.get(f"{self.base}chapters/{chapter_id}/verses", kwargs)

    def get_verse(self, chapter_id, verse_id) -> Dict:
        """
        Get a single verse_id from a specific chapter_id

        args:
            chapter_id      Integer
            verse_id        Integer
        """
        return self.rq.get(f"{self.base}chapters/{chapter_id}/verses/{verse_id}")

    def get_juzs(self) -> Dict:
        return self.rq.get(f"{self.base}juzs")

    def get_tafsirs_from_verse_id(self, chapter_id, verse_id) -> Dict:
        """
        Returns all Tafsir from a verse_id

        args:
            chapter_id
            verse_id

        returns:
            json Object
        """
        return self.rq.get(f"{self.base}chapters/{chapter_id}/verses/{verse_id}/tafsirs")

    def get_tafsir_from_verse_id(self, chapter_id, verse_id, **kwargs) -> Dict:
        """
        Returns a single Tafsir from a verse_id

        args:
            chapter_id
            verse_id
            tafsirs     Optional

        returns:
            json Object
        """
        return self.rq.get(f"{self.base}chapters/{chapter_id}/verses/{verse_id}/tafsirs", kwargs)

    def search(self, **kwargs) -> Dict:
        """
        args:
            q           Search query, you can use query as well (optional)
            size        Results per page. s is also valid parameter. (default: 20, optional)
            page        Page number, well for pagination. You can use p as well (default: 0, optional
            language    ISO code of language, use this query params if you want to boost translations for specific language. (default: en, optional)

        returns:
            json Object
        """
        return self.rq.get(f"{self.base}search", kwargs)




#!/usr/bin/env python3
# -*- coding:utf-8 -*-
###
# File: extractMethids.py
# Created: Thursday, 6th August 2020 12:24:03 pm
# Author: Rakibul Yeasin (ryeasin03@gmail.com)
# -----
# Last Modified: Thursday, 6th August 2020 12:52:57 pm
# Modified By: Rakibul Yeasin (ryeasin03@gmail.com)
# -----
# Copyright (c) 2020 Slishee
###

import os

with open(os.path.join(os.path.dirname(__file__), 'Sunnah_api.py'), "r") as sunnah:
    for line in sunnah.readlines():
        if line.startswith('    def'):
            name = line.split(" ")[5].split("(")[0]
            with open("Sunnah_methods.txt", "a") as s_methods:
                s_methods.write(name + "\n")

with open(os.path.join(os.path.dirname(__file__), 'Quran_api.py'), "r") as sunnah:
    for line in sunnah.readlines():
        if line.startswith('    def'):
            name = line.split(" ")[5].split("(")[0]
            with open("Quran_methods.txt", "a") as s_methods:
                s_methods.write(name + "\n")



from os import path
import io

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

__author__ = 'dreygur <ryeasin03@gmail.com>'
__version__ = '1.0.0'

packages = [
    'quran'
]

with io.open(path.join(path.abspath(path.dirname(__file__)), 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

with open('requirements.txt', 'r') as f:
    requirements_inside = f.readlines()

setup(
    name='quran',
    version=__version__,
    author='dreygur',
    author_email='ryeasin03@gmail.com',
    license='MIT',
    url='https://github.com/dreygur/Quran.com/tree/master',
    install_requires=requirements_inside,
    keywords='quran api',
    description='A python wrapper quran.com api.',
    long_description=long_description,
    long_description_content_type='text/markdown',
    packages=packages,
    platforms=['any'],
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Programming Language :: Python :: 3.8',
    ]
)



#!/usr/bin/env python3
# -*- coding:utf-8 -*-
###
# File: exceptions.py
# Created: Tuesday, 28th July 2020 4:33:53 pm
# Author: Rakibul Yeasin (ryeasin03@gmail.com)
# -----
# Last Modified: Wednesday, 29th July 2020 12:11:31 am
# Modified By: Rakibul Yeasin (ryeasin03@gmail.com)
# -----
# Copyright (c) 2020 Slishee
###

class LanguageNotAvailable(Exception):
    pass

class ChapterNumberNotFound(Exception):
    pass

class CollectionNameNotFound(Exception):
    pass

class CollectionNameOrIdNotFound(Exception):
    pass